/*
 * filter registration
 * Copyright (c) 2008 Vitor Sessak
 *
 * This file is part of FFmpeg.
 *
 * FFmpeg is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * FFmpeg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with FFmpeg; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "avfilter.h"
#include "config.h"


#define REGISTER_FILTER(X,x,y) { \
          extern AVFilter avfilter_##y##_##x ; \
          if(CONFIG_##X##_FILTER )  avfilter_register(&avfilter_##y##_##x ); }

#define REGISTER_BUILTIN_FILTER(x,y) { \
          extern AVFilter avfilter_##y##_##x ; \
          avfilter_register(&avfilter_##y##_##x ); }

void avfilter_register_all(void)
{
    static int initialized;

    if (initialized)
        return;
    initialized = 1;

    REGISTER_FILTER (AFORMAT,     aformat,     af);
    REGISTER_FILTER (ANULL,       anull,       af);
    REGISTER_FILTER (FORMAT,      format,      vf);
    REGISTER_FILTER (NULL,        null,        vf);
    REGISTER_FILTER (SETPTS,      setpts,      vf);

    /* those filters are part of public or internal API => registered
     * unconditionally */
    {
        extern AVFilter avfilter_vsrc_buffer;
        avfilter_register(&avfilter_vsrc_buffer);
    }
    {
        extern AVFilter avfilter_asrc_abuffer;
        avfilter_register(&avfilter_asrc_abuffer);
    }
    {
        extern AVFilter avfilter_vsink_buffer;
        avfilter_register(&avfilter_vsink_buffer);
    }
    {
        extern AVFilter avfilter_asink_abuffer;
        avfilter_register(&avfilter_asink_abuffer);
    }
}
